@@ -5,7 +5,7 @@ from pathlib import Path
 
 
 def update_version(package: str = 'dummy_autoupdate', version: str = None,
-                   num_of_attempts: int = 2) -> bool:
+                   num_of_attempts: int = 3) -> bool:
     logger = logging.getLogger(__name__)
 
     if version:
@@ -29,12 +29,11 @@ def update_version(package: str = 'dummy_autoupdate', version: str = None,
     for i in range(num_of_attempts):
         try:
             logger.info(f'Updating the package with {executable} (attempt {i + 1}).')
-            res = subprocess.check_call([executable, "-m", "pip", "install", "--upgrade", package],
-                                        creationflags=CREATE_NO_WINDOW)
-            logger.info(f'res = {res}')
+            subprocess.check_call([executable, "-m", "pip", "install", "--upgrade", package],
+                                  creationflags=CREATE_NO_WINDOW)
             return True
 
         except subprocess.CalledProcessError:
-            pass
+            continue
 
     return False
